



ipfs --version
IF %ERRORLEVEL% NEQ 0 exit /B 1
ipfs --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
ipfs commands
IF %ERRORLEVEL% NEQ 0 exit /B 1
ipfs -c ./.ipfs-repo --debug init
IF %ERRORLEVEL% NEQ 0 exit /B 1
ipfs -c ./.ipfs-repo --debug ls /ipfs/QmQPeNsJPyVWPFDVHb77w8G42Fvo15z4bG2X8D2GhfbSXc
IF %ERRORLEVEL% NEQ 0 exit /B 1
ipfs -c ./.ipfs-repo --debug refs /ipfs/QmQPeNsJPyVWPFDVHb77w8G42Fvo15z4bG2X8D2GhfbSXc
IF %ERRORLEVEL% NEQ 0 exit /B 1
ipfs -c ./.ipfs-repo --debug cat /ipfs/QmQPeNsJPyVWPFDVHb77w8G42Fvo15z4bG2X8D2GhfbSXc/readme
IF %ERRORLEVEL% NEQ 0 exit /B 1
ipfs -c ./.ipfs-repo --debug get /ipfs/QmQPeNsJPyVWPFDVHb77w8G42Fvo15z4bG2X8D2GhfbSXc
IF %ERRORLEVEL% NEQ 0 exit /B 1
echo 'hello world' > hello.txt
IF %ERRORLEVEL% NEQ 0 exit /B 1
ipfs -c ./.ipfs-repo --debug add hello.txt
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
